@@ -1,8 +1,9 @@
-from PIL import Image
-from image import FileImage
-from spriter.image import URLImage
 import os
 
+from PIL import Image
+
+from spriter.image import FileImage, URLImage, class_name_function
+
 
 class DefaultImageDoesNotExist(Exception):
     message = "The default image path must be exist. Not found in: "
@@ -15,8 +16,8 @@ class DefaultImageDoesNotExist(Exception):
 
 class Sprite(object):
 
-    __CSS_TEMPLATE = ".{CLASSES}{{background:url(\"{ROOT_PATH}{SPRITE_NAME}\") 0 0 no-repeat}}"
-    __CSS_CLASS_TEMPLATE = ".{CLASSES}.{CLASS_NAME}{{background-position: {POSITION_X}px {POSITION_Y}px}}"
+    __CSS_TEMPLATE = ".{self.class_name}{{background:url(\"{self.sprite_url}{self.sprite_name}\") 0 0 no-repeat}}"
+    __CSS_CLASS_TEMPLATE = ".{self.class_name}.{image.class_name}{{background-position: {image.sprite_coordinate_x}px {image.sprite_coordinate_y}px}}"
 
     def __init__(self,
                  paths=[],
@@ -28,9 +29,10 @@ class Sprite(object):
                  css_path="",
                  class_name="sprite",
                  css_name="sprite.css",
-                 optimize=False,
+                 optimize=True,
                  default_path="",
-                 default_url=""):
+                 default_url="",
+                 class_name_function=class_name_function):
 
         self.images = []
         self.height = 0
@@ -44,11 +46,13 @@ class Sprite(object):
                 raise DefaultImageDoesNotExist(default_path)
 
         for path in paths:
-            img = FileImage(path, default_path)
+            img = FileImage(path, default_path,
+                            class_name_function=class_name_function)
             self.images.append(img)
 
         for path in urls_paths:
-            img = URLImage(path, default_url)
+            img = URLImage(path, default_url,
+                           class_name_function=class_name_function)
             self.images.append(img)
 
         if sprite_name:
@@ -84,19 +88,11 @@ class Sprite(object):
 
     def get_css(self):
         """given the sprite's css string"""
-        css_line = []
+        css_line = [self.__CSS_TEMPLATE.format(self=self)]
 
         for image in self.images:
             css_line.append(
-                    self.__CSS_CLASS_TEMPLATE.format(CLASSES=self.class_name,
-                                                CLASS_NAME=image.class_name,
-                                        POSITION_X=image.sprite_coordinate_x,
-                                        POSITION_Y=image.sprite_coordinate_y))
-
-        base = self.__CSS_TEMPLATE.format(CLASSES=self.class_name,
-                                       ROOT_PATH=self.sprite_url,
-                                       SPRITE_NAME=self.sprite_name)
-        css_line.insert(0, base)
+                    self.__CSS_CLASS_TEMPLATE.format(self=self, image=image))
         css = "".join(css_line)
         return css
 
@@ -106,11 +102,9 @@ class Sprite(object):
             os.makedirs(self.css_path)
 
         path = os.path.join(self.css_path, self.css_name)
-
-        css_f = open(path, "w")
-        css = self.get_css()
-        css_f.write(css)
-        css_f.close()
+        with open(path, "w") as css_f:
+            css = self.get_css()
+            css_f.write(css)
         return path
 
     def gen_image(self):
@@ -131,7 +125,8 @@ class Sprite(object):
             os.makedirs(self.sprite_path)
         path = os.path.join(self.sprite_path, self.sprite_name)
         if self.optimize:
-            self.image.save(path, "PNG", optimize=1)
+            self.image.save(path, "PNG",
+                            optimize=1, compress_level=2, compress_type=1)
         else:
             self.image.save(path, "PNG")
         return path
